@@ -51,13 +51,19 @@
 
 class OpProgress;
 class pkgVersioningSystem;
+namespace APT
+{
+template <class Container>
+class PackageContainer;
+using PackageVector = PackageContainer<std::vector<pkgCache::PkgIterator>>;
+} // namespace APT
 
-class pkgDepCache : protected pkgCache::Namespace
+class APT_PUBLIC pkgDepCache : protected pkgCache::Namespace
 {
    public:
 
    /** \brief An arbitrary predicate on packages. */
-   class InRootSetFunc
+   class APT_PUBLIC InRootSetFunc
    {
    public:
      virtual bool InRootSet(const pkgCache::PkgIterator &/*pkg*/) {return false;};
@@ -156,7 +162,7 @@ class pkgDepCache : protected pkgCache::Namespace
     *  to a std::set of pointers to them and use those to store
     *  information about what happened in a group in the group.
     */
-   class ActionGroup
+   class APT_PUBLIC ActionGroup
    {
        void * const d;
        pkgDepCache &cache;
@@ -193,7 +199,7 @@ class pkgDepCache : protected pkgCache::Namespace
    /** \brief Returns \b true for packages matching a regular
     *  expression in APT::NeverAutoRemove.
     */
-   class DefaultRootSetFunc : public InRootSetFunc, public Configuration::MatchAgainstConfig
+   class APT_PUBLIC DefaultRootSetFunc : public InRootSetFunc, public Configuration::MatchAgainstConfig
    {
    public:
      DefaultRootSetFunc() : Configuration::MatchAgainstConfig("APT::NeverAutoRemove") {};
@@ -202,7 +208,7 @@ class pkgDepCache : protected pkgCache::Namespace
      bool InRootSet(const pkgCache::PkgIterator &pkg) APT_OVERRIDE { return pkg.end() == false && Match(pkg.Name()); };
    };
 
-   struct StateCache
+   struct APT_PUBLIC StateCache
    {
       // text versions of the two version fields
       const char *CandVersion;
@@ -264,7 +270,7 @@ class pkgDepCache : protected pkgCache::Namespace
    void UpdateVerState(PkgIterator const &Pkg);
 
    // User Policy control
-   class Policy
+   class APT_PUBLIC Policy
    {
       public:
       Policy() {
@@ -362,6 +368,7 @@ class pkgDepCache : protected pkgCache::Namespace
    inline StateCache &operator [](PkgIterator const &I) {return PkgState[I->ID];};
    inline StateCache &operator [](PkgIterator const &I) const {return PkgState[I->ID];};
    inline unsigned char &operator [](DepIterator const &I) {return DepState[I->ID];};
+   inline unsigned char const &operator [](DepIterator const &I) const {return DepState[I->ID];};
 
    /** \return A function identifying packages in the root set other
     *  than manually installed packages and essential packages, or \b
@@ -495,6 +502,8 @@ class pkgDepCache : protected pkgCache::Namespace
    pkgDepCache(pkgCache * const Cache,Policy * const Plcy = 0);
    virtual ~pkgDepCache();
 
+   bool CheckConsistency(char const *const msgtag = "");
+
    protected:
    // methods call by IsInstallOk
    bool IsInstallOkMultiArchSameVersionSynced(PkgIterator const &Pkg,
@@ -509,8 +518,10 @@ class pkgDepCache : protected pkgCache::Namespace
    private:
    void * const d;
 
-   APT_HIDDEN bool IsModeChangeOk(ModeList const mode, PkgIterator const &Pkg,
-			unsigned long const Depth, bool const FromUser);
+   APT_HIDDEN bool MarkInstall_StateChange(PkgIterator const &Pkg, bool AutoInst, bool FromUser);
+   APT_HIDDEN bool MarkInstall_DiscardInstall(PkgIterator const &Pkg);
+
+   APT_HIDDEN void PerformDependencyPass(OpProgress * const Prog);
 };
 
 #endif
