@@ -214,8 +214,6 @@ map_id_t pkgCache::sHash(StringView Str) const
    return Hash % HeaderP->GetHashTableSize();
 }
 
-#if defined(HAVE_FMV_SSE42_AND_CRC32)
-
 #ifdef HAVE_FMV_SSE42_AND_CRC32
 __attribute__((target("sse4.2"))) static uint32_t hash32(uint32_t crc32, const unsigned char *input, size_t size)
 {
@@ -253,7 +251,6 @@ __attribute__((target("sse4.2"))) static uint32_t hash32(uint32_t crc32, const u
    crc32 ^= 0xffffffffU;
    return crc32;
 }
-#endif
 
 __attribute__((target("default")))
 #endif
@@ -274,6 +271,10 @@ uint32_t pkgCache::CacheHash()
    header.Dirty = false;
    header.CacheFileSize = 0;
 
+   adler = hash32(adler,
+		  reinterpret_cast<const unsigned char *>(PACKAGE_VERSION),
+		  APT_ARRAY_SIZE(PACKAGE_VERSION));
+
    adler = hash32(adler,
 		  reinterpret_cast<const unsigned char *>(&header),
 		  sizeof(header));
@@ -381,7 +382,7 @@ const char *pkgCache::Priority(unsigned char Prio)
 {
    const char *Mapping[] = {0,_("required"),_("important"),_("standard"),
                             _("optional"),_("extra")};
-   if (Prio < _count(Mapping))
+   if (Prio < APT_ARRAY_SIZE(Mapping))
       return Mapping[Prio];
    return 0;
 }
@@ -447,7 +448,7 @@ pkgCache::PkgIterator pkgCache::GrpIterator::NextPkg(pkgCache::PkgIterator const
 	    LastPkg.end() == true))
 		return PkgIterator(*Owner, 0);
 
-	if (S->LastPackage == LastPkg.Index())
+	if (S->LastPackage == LastPkg.MapPointer())
 		return PkgIterator(*Owner, 0);
 
 	return PkgIterator(*Owner, Owner->PkgP + LastPkg->NextPackage);
@@ -991,6 +992,23 @@ string pkgCache::PkgFileIterator::RelStr()				/*{{{*/
       Res = Res + (Res.empty() == true?"b=":",b=")  + Architecture();
    return Res;
 }
+									/*}}}*/
+// VerIterator::TranslatedDescriptionForLanguage - Return a DescIter for language/*{{{*/
+// ---------------------------------------------------------------------
+/* return a DescIter for the specified language
+ */
+pkgCache::DescIterator pkgCache::VerIterator::TranslatedDescriptionForLanguage(StringView lang) const
+{
+   for (pkgCache::DescIterator Desc = DescriptionList(); Desc.end() == false; ++Desc)
+      if (lang == Desc.LanguageCode())
+         return Desc;
+
+   if (lang == "en")
+      return TranslatedDescriptionForLanguage("");
+
+   return DescIterator();
+}
+
 									/*}}}*/
 // VerIterator::TranslatedDescription - Return the a DescIter for locale/*{{{*/
 // ---------------------------------------------------------------------
@@ -1003,30 +1021,15 @@ pkgCache::DescIterator pkgCache::VerIterator::TranslatedDescription() const
    for (std::vector<string>::const_iterator l = lang.begin();
 	l != lang.end(); ++l)
    {
-      pkgCache::DescIterator Desc = DescriptionList();
-      for (; Desc.end() == false; ++Desc)
-	 if (*l == Desc.LanguageCode())
-	    break;
-      if (Desc.end() == true)
-      {
-	 if (*l == "en")
-	 {
-	    Desc = DescriptionList();
-	    for (; Desc.end() == false; ++Desc)
-	       if (strcmp(Desc.LanguageCode(), "") == 0)
-		  break;
-	    if (Desc.end() == true)
-	       continue;
-	 }
-	 else
-	    continue;
-      }
-      return Desc;
+      pkgCache::DescIterator Desc = TranslatedDescriptionForLanguage(*l);
+      if (Desc.IsGood())
+         return Desc;
    }
-   for (pkgCache::DescIterator Desc = DescriptionList();
-	Desc.end() == false; ++Desc)
-      if (strcmp(Desc.LanguageCode(), "") == 0)
-	 return Desc;
+
+   pkgCache::DescIterator Desc = TranslatedDescriptionForLanguage("");
+   if (Desc.IsGood())
+      return Desc;
+
    return DescriptionList();
 }
 
